summaryrefslogtreecommitdiff
path: root/benchmarks/CUDA/template/template_kernel.cu
diff options
context:
space:
mode:
authorTor Aamodt <[email protected]>2010-07-15 18:09:46 -0800
committerTor Aamodt <[email protected]>2010-07-15 18:09:46 -0800
commit69f2911e04ffb1b19eef1fafb8c040af271f656e (patch)
tree231d3b6bdc3a202f7c255bfcf7bf2c36e32cee9e /benchmarks/CUDA/template/template_kernel.cu
creating branch for adding support for CUDA 3.x and Fermi
[git-p4: depot-paths = "//depot/gpgpu_sim_research/fermi/distribution/": change = 6829]
Diffstat (limited to 'benchmarks/CUDA/template/template_kernel.cu')
-rw-r--r--benchmarks/CUDA/template/template_kernel.cu79
1 files changed, 79 insertions, 0 deletions
diff --git a/benchmarks/CUDA/template/template_kernel.cu b/benchmarks/CUDA/template/template_kernel.cu
new file mode 100644
index 0000000..2e8f035
--- /dev/null
+++ b/benchmarks/CUDA/template/template_kernel.cu
@@ -0,0 +1,79 @@
+/*
+ * Copyright 1993-2007 NVIDIA Corporation. All rights reserved.
+ *
+ * NOTICE TO USER:
+ *
+ * This source code is subject to NVIDIA ownership rights under U.S. and
+ * international Copyright laws. Users and possessors of this source code
+ * are hereby granted a nonexclusive, royalty-free license to use this code
+ * in individual and commercial software.
+ *
+ * NVIDIA MAKES NO REPRESENTATION ABOUT THE SUITABILITY OF THIS SOURCE
+ * CODE FOR ANY PURPOSE. IT IS PROVIDED "AS IS" WITHOUT EXPRESS OR
+ * IMPLIED WARRANTY OF ANY KIND. NVIDIA DISCLAIMS ALL WARRANTIES WITH
+ * REGARD TO THIS SOURCE CODE, INCLUDING ALL IMPLIED WARRANTIES OF
+ * MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE.
+ * IN NO EVENT SHALL NVIDIA BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL,
+ * OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
+ * OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
+ * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE
+ * OR PERFORMANCE OF THIS SOURCE CODE.
+ *
+ * U.S. Government End Users. This source code is a "commercial item" as
+ * that term is defined at 48 C.F.R. 2.101 (OCT 1995), consisting of
+ * "commercial computer software" and "commercial computer software
+ * documentation" as such terms are used in 48 C.F.R. 12.212 (SEPT 1995)
+ * and is provided to the U.S. Government only as a commercial end item.
+ * Consistent with 48 C.F.R.12.212 and 48 C.F.R. 227.7202-1 through
+ * 227.7202-4 (JUNE 1995), all U.S. Government End Users acquire the
+ * source code with only those rights set forth herein.
+ *
+ * Any use of this source code in individual and commercial software must
+ * include, in the user documentation and internal comments to the code,
+ * the above Disclaimer and U.S. Government End Users Notice.
+ */
+
+/* Template project which demonstrates the basics on how to setup a project
+ * example application.
+ * Device code.
+ */
+
+#ifndef _TEMPLATE_KERNEL_H_
+#define _TEMPLATE_KERNEL_H_
+
+#include <stdio.h>
+
+#define SDATA( index) cutilBankChecker(sdata, index)
+
+////////////////////////////////////////////////////////////////////////////////
+//! Simple test kernel for device functionality
+//! @param g_idata input data in global memory
+//! @param g_odata output data in global memory
+////////////////////////////////////////////////////////////////////////////////
+__global__ void
+testKernel( float* g_idata, float* g_odata)
+{
+ // shared memory
+ // the size is determined by the host application
+ extern __shared__ float sdata[];
+
+ // access thread id
+ const unsigned int tid = threadIdx.x;
+ // access number of threads in this block
+ const unsigned int num_threads = blockDim.x;
+
+ // read in input data from global memory
+ // use the bank checker macro to check for bank conflicts during host
+ // emulation
+ SDATA(tid) = g_idata[tid];
+ __syncthreads();
+
+ // perform some computations
+ SDATA(tid) = (float) num_threads * SDATA( tid);
+ __syncthreads();
+
+ // write data to global memory
+ g_odata[tid] = SDATA(tid);
+}
+
+#endif // #ifndef _TEMPLATE_KERNEL_H_